@@ -312,6 +312,6 @@ class SapGuiLibraryExtended():
             raise ValueError(message)
         time.sleep(self.explicit_wait)
 
-    def test(name):
-        a = print("Hello World", name)
+    def test(self, name):
+        a = print("Hello", name)
         return(a)
\ No newline at end of file
