@@ -1,6 +1,6 @@
 
 
-__version__ = '0.4.4'
+__version__ = '0.4.6'
 __author__ = 'Daniela Silva'
 
 
@@ -318,6 +318,6 @@ class SapGuiLibraryExtended():
             raise ValueError(message)
         time.sleep(self.explicit_wait)
 
-    def test(name):
-        a = print("Hello World", name)
+    def test(self, name):
+        a = print("Hello", name)
         return(a)
\ No newline at end of file
